#### Supporting Material for the manuscript "Subarctic soil carbon losses after deforestation for agriculture depend on permafrost abundance"
#### by T. Peplau, J. Schroeder, E. Gregorich and C. Poeplau

# load required libraries
library(dplyr)
library(emmeans)
library(ggplot2)
library(ggpubr)
library(ggthemes)
library(lme4)
library(lmerTest)
library(readxl)

# set working diretory to the desired path
setwd("C:/path/to/dataset")

# read soil data
data_complete <- read_excel("Soil_data_Peplau_et_al_2022.xlsx", na = "NA") %>%
  filter(., Location != "LR" | Land_Use != "Co") %>% # removed, as it turned out later that this plot was not comparable to the others
  filter(., plot != "LR_oC") %>% # removed for the same reason
  filter(., plot_rep != "KK_C_1") # removed, as this core contained erroneous data

# since there was no need to distinguish between old and young cropland (Co and Cy), land-use nomenclature can be unified
data_complete$Land_Use[data_complete$Land_Use=="Co"] <- "C"
data_complete$Land_Use[data_complete$Land_Use=="Cy"] <- "C"
data_complete$Land_Use <- factor(data_complete$Land_Use, levels = c("F", "C", "G")) # sets the levels for further analyses
data_complete$`Litter C [Mg ha]`[is.na(data_complete$`Litter C [Mg ha]`)] <- 0


data_complete <- data_complete %>% mutate(log_C_Complete = log(data_complete$C_Complete))


MS_data <- filter(data_complete, rep == 6) # MS_data: mixed core samples, as described in the manuscript
SS_data <- filter(data_complete, rep != 6) # SS_data: indivdual core samples

# calculates the absolute amount of each fraction, corrected for the total organic carbon. This needs to be done, to account for the lab-error in the fractions
MS_data <- MS_data %>%
  mutate(POM_C = (POM_relative*`TOC [g/kg]`),
         DOC = (DOC_relative*`TOC [g/kg]`),
         SA_C = (SA_relative*`TOC [g/kg]`),
         SC_C = (SC_rSOC_relative*`TOC [g/kg]`),
         SC_inkl_rSOC = (SC_relative*`TOC [g/kg]`),
         rSOC = (rSOC_relative*`TOC [g/kg]`),
         POM_SA = POM_relative + SA_relative,
         MAOM = SC_relative+DOC_relative)

# summarise data for each site 
sites <- SS_data %>% 
  filter(., Depth == 70 | Location == "NB" & Depth == 30) %>%
  filter(., Location!= "NO") %>%
  dplyr::select(., c(Location, Land_Use, forest_A_Horizon_thickness, Permafrost,`Corrected stock`, C_Complete, Age, Permafrost_depth, `Litter C [Mg ha]`, Profile_CN,Sand, Silt,`T < 2`,Olsen_P_mg_per_kg,ph,
                     cumulative_degree_days,frost_days,precipitation,temperature,longitude,latitude, POM_relative, DOC_relative, SA_relative, SC_relative, rSOC_relative)) %>%
  group_by(Location, Land_Use) %>%
  dplyr::summarise(mineral_stock= mean(`Corrected stock`),
                   stock = mean(C_Complete),
                   Age = mean(Age[Land_Use !="F"]),
                   Permafrost = first(Permafrost[Land_Use == "F"]),
                   Permafrost_depth = first(Permafrost_depth[Land_Use == "F"]),
                   forest_a_horizon = mean(forest_A_Horizon_thickness),
                   Litter_C = first(`Litter C [Mg ha]`[Land_Use == "F"]),
                   Profile_CN = mean(Profile_CN),
                   Sand = mean(Sand),
                   Silt = mean(Silt),
                   Clay = mean(`T < 2`),
                   Olsen_P = mean(Olsen_P_mg_per_kg),
                   ph = mean(ph),
                   cumulative_degree_days = mean(cumulative_degree_days),
                   frost_days = mean(frost_days),
                   precipitation = mean(precipitation),
                   temperature = mean(temperature),
                   longitude = mean(longitude),
                   latitude = mean(latitude)) %>%
  group_by(Location) %>%
  dplyr::summarise(forest_stock = stock[Land_Use == "F"],
                   mineral_forest = mineral_stock[Land_Use == "F"],
                   new_stock = stock[Land_Use!="F"],
                   Change = Land_Use[Land_Use!="F"],
                   RR = ((new_stock-forest_stock)/forest_stock)*100,
                   Loss = new_stock-forest_stock,
                   Permafrost = Permafrost[Land_Use == "F"],
                   Age = Age[Land_Use!="F"],
                   Permafrost_depth = Permafrost_depth[Land_Use == "F"],
                   forest_a_horizon = forest_a_horizon[Land_Use == "F"],
                   Litter_C = Litter_C[Land_Use == "F"],
                   Profile_CN_F = Profile_CN[Land_Use == "F"],
                   Profile_CN_A = Profile_CN[Land_Use != "F"],
                   Sand_F = Sand[Land_Use=="F"],
                   Sand_A = Sand[Land_Use!="F"],
                   Silt_F = Silt[Land_Use=="F"],
                   Silt_A = Silt[Land_Use!= "F"],
                   Clay_F = Clay[Land_Use=="F"],
                   Clay_A = Clay[Land_Use!="F"],
                   Olsen_P_F = Olsen_P[Land_Use=="F"],
                   Olsen_P_A = Olsen_P[Land_Use!="F"],
                   ph_F = ph[Land_Use=="F"],
                   ph_A = ph[Land_Use!="F"],
                   cumulative_degree_days = cumulative_degree_days[Land_Use=="F"],
                   frost_days = frost_days[Land_Use=="F"],
                   precipitation = precipitation[Land_Use=="F"],
                   temperature = temperature[Land_Use=="F"],
                   longitude = longitude[Land_Use=="F"],
                   latitude = latitude[Land_Use=="F"]) %>%
  mutate(Change_PF = paste0(Change,c("_"), Permafrost))


site_fractions <- MS_data %>%
  filter(., Depth == 15) %>%
  filter(., Location!= "NO") %>%
  dplyr::select(., c(Location, Land_Use, POM_C, DOC, SA_C, SC_C, rSOC)) %>%
  group_by(Location) %>%
  dplyr::summarise(Change = Land_Use[Land_Use!="F"],
                   forest_POM = POM_C[Land_Use == "F"],
                   new_POM = POM_C[Land_Use!="F"],
                   delta_POM = new_POM-forest_POM,
                   forest_DOC = DOC[Land_Use == "F"],
                   new_DOC = DOC[Land_Use!="F"],
                   delta_DOC = new_DOC-forest_DOC,
                   forest_SA = SA_C[Land_Use == "F"],
                   new_SA = SA_C[Land_Use!="F"],
                   delta_SA = new_SA-forest_SA,
                   forest_SC = SC_C[Land_Use == "F"],
                   new_SC = SC_C[Land_Use!="F"],
                   delta_SC = new_SC-forest_SC,
                   forest_rSOC = rSOC[Land_Use == "F"],
                   new_rSOC = rSOC[Land_Use!="F"],
                   delta_rSOC = new_rSOC-forest_POM)

# connect fractionation-data and site data for the correlation analyses
sites_cor <- dplyr::right_join(sites, site_fractions, by=c("Location", "Change"))

# set labels for plots
labs = c("C" = "Cropland",
         "G" = "Grassland",
         "No" = "No permafrost",
         "Yes" = "Permafrost",
         "C_No" = "Cropland, \n no permafrost",
         "C_Yes" = "Cropland, \n permafrost",
         "G_No" = "Grassland, \n no permafrost",
         "G_Yes" = "Grassland, \n permafrost",
         "Topsoil" = "Topsoil",
         "Subsoil" = "Subsoil")

permafrost_labs <- c('CD' = "CD",
                     'DR' = "DR",
                     'DW' = "DW",
                     'EF' = "EF",
                     'EG' = "EG",
                     'GV' = "GV",
                     'KK' = "KK",
                     'KL' = "KL",
                     'LR' = "LR",
                     'MA' = "MA",
                     'MG' = "MG",
                     'NB' = "NB",
                     'PC' = "PC",
                     'RC' = "RC",
                     'RFo' = "RFo",
                     'RFy' = "RFy",
                     'SI' = "SI",
                     'TH' = "TH",
                     'VE' = "VE")

#####  Summary of the the carbon stocks (Table 2)---------
stock_summary <- sites %>%
  filter(Location != "NO") %>%
  group_by(Change_PF) %>%
  dplyr::summarise(mean_mineral_forest = mean(mineral_forest),
                   sd_mineral_forest = sd(mineral_forest),
                   mean_forest_stock = mean(forest_stock),
                   sd_forest_stock = sd(forest_stock),
                   mean_new_stock = mean(new_stock),
                   sd_new_stock = sd(new_stock),
                   litter_mean = mean(Litter_C),
                   litter_sd = sd(Litter_C),
                   mean_Loss = mean(Loss),
                   sd_Loss = sd(Loss),
                   mean_RR = mean(RR),
                   sd_RR = sd(RR),
                   n = n()) 



#### LME-------- 
# linear mixed effects model to describe connection between Permafrost and Land use change

fit_data_grassland <- SS_data %>%
  filter(., Depth == 70) %>%
  filter(., Location =="DR" |
           Location =="DW" |
           Location =="MA" |
           Location =="PC" |
           Location=="TH"|
           Location=="CD"|
           Location=="EF"|
           Location=="GV"|
           Location=="MG"|
           Location=="VE") %>%
  filter(., Land_Use =="F" | Land_Use=="G")

fit_data_cropland <- SS_data %>%
  filter(., Depth == 70) %>%
  filter(., Location =="KK" |
           Location =="KL" |
           Location =="PC" |
           Location =="RC" |
           Location=="RFo"|
           Location=="RFy"|
           Location=="TH"|
           Location=="CD"|
           Location=="GV"|
           Location=="LR"|
           Location=="MG"|
           Location=="VE") %>%
  filter(., Land_Use =="F" | Land_Use=="C")


# check for assumptions of anova
# plot(resid(fit_cropland))
# plot(resid(fit_grassland))
# 
# fit_data_cropland$Model.F.Res<- residuals(fit_cropland) #extracts the residuals and places them in a new column in our original data table
# fit_data_cropland$Abs.Model.F.Res <-abs(fit_data_cropland$Model.F.Res) #creates a new column with the absolute value of the residuals
# fit_data_cropland$Model.F.Res2 <- fit_data_cropland$Abs.Model.F.Res^2 #squares the absolute values of the residuals to provide the more robust estimate
# Levene.Model.F <- lm(Model.F.Res2 ~ Location, data=fit_data_cropland) #ANOVA of the squared residuals
# anova(Levene.Model.F) #displays the results
# 
# 
# fit_data_grassland$Model.F.Res<- residuals(fit_grassland) #extracts the residuals and places them in a new column in our original data table
# fit_data_grassland$Abs.Model.F.Res <-abs(fit_data_grassland$Model.F.Res) #creates a new column with the absolute value of the residuals
# fit_data_grassland$Model.F.Res2 <- fit_data_grassland$Abs.Model.F.Res^2 #squares the absolute values of the residuals to provide the more robust estimate
# Levene.Model.F2 <- lm(Model.F.Res2 ~ Location, data=fit_data_grassland) #ANOVA of the squared residuals
# anova(Levene.Model.F2)
# 
# qqmath(fit_cropland, id=0.05)
# qqmath(fit_grassland, id=0.05)

fit_data_complete <- SS_data %>% filter(., Depth == 70)

fit_grassland <- lmer(log_C_Complete ~ Land_Use*Permafrost + (1|Location), data = fit_data_grassland)
anova(fit_grassland)
summary(fit_grassland)
emmeans(fit_grassland, list(pairwise ~ Permafrost*Land_Use), adjust = "tukey")

fit_cropland <- lmer(log_C_Complete ~ Land_Use*Permafrost + (1|Location), data = fit_data_cropland)
anova(fit_cropland)
summary(fit_cropland)
emmeans(fit_cropland, list(pairwise ~ Permafrost*Land_Use), adjust = "tukey")

fit_together <- lmer(log_C_Complete ~ Permafrost*Land_Use + (1|Location), data = fit_data_complete)
anova(fit_together)
summary(fit_together)
emmeans(fit_together, list(pairwise ~ Permafrost*Land_Use), adjust = "tukey")


#### Figure 3: Pointrange of SOC changes -------------
relative <- sites %>%
  filter(., Location != "NO") %>%
  group_by(Change_PF) %>%
  dplyr::summarise(test = if (list(t.test(x=log(new_stock), y=log(forest_stock), var.equal = TRUE, paired = TRUE, alternative = "less")[[3]])>0.05){"n.s"}
                   else {"p<0.05"},
                   mean_RR = mean(RR),
                   sd_RR = sd(RR)) %>%
  ggplot(aes(x=Change_PF, y=mean_RR))+
  geom_pointrange(aes(y=mean_RR, ymin = mean_RR-sd_RR, ymax = mean_RR+sd_RR, x = Change_PF))+
  geom_text(aes(label=test, y=-42))+
  annotate(geom = "text", label="(a)", y=20, x=4.4, fontface = "bold")+
  scale_x_discrete(labels = labs)+
  geom_abline(slope = 0, intercept = 0)+
  ylab("Relative change of SOC [%]")+
  xlab(NULL)+
  theme_bw()+
  theme(legend.position = "none")+
  scale_color_colorblind()


absolute <- sites %>%
  filter(Location != "NB") %>%
  filter(Location != "NO") %>%
  group_by(Change_PF) %>%
  dplyr::summarise(test = if (list(t.test(x=log(new_stock), y=log(forest_stock), var.equal = TRUE, paired = TRUE, alternative = "less")[[3]])>0.05){"n.s"}
                   else {"p<0.05"},
                   mean_Loss = mean(Loss),
                   sd_Loss = sd(Loss)) %>%
  ggplot(aes(x=Change_PF, y=mean_Loss))+
  geom_pointrange(aes(y=mean_Loss, ymin = mean_Loss-sd_Loss, ymax = mean_Loss+sd_Loss, x = Change_PF))+
  geom_text(aes(label=test, y=-80))+
  annotate(geom = "text", label="(b)", y=+25, x=4.4, fontface = "bold")+
  scale_x_discrete(labels = labs)+
  geom_abline(slope = 0, intercept = 0)+
  ylab("Absolute change of SOC [Mg/ha]")+
  xlab("Permafrost and land use change")+
  theme_bw()+
  theme(legend.position = "none")+
  scale_color_colorblind()

figure_3 <- ggarrange(relative, absolute, ncol = 1) 

figure_3


###### Figure 4: Relative change of the fractions as donut-plot----------

fractions_topsoil_rel <- MS_data %>%
  filter(., Depth == 15) %>%
  dplyr::select(., c(Location, Land_Use,Permafrost,  POM_relative, DOC_relative, SA_relative, SC_rSOC_relative, rSOC_relative)) %>%
  group_by(Location) %>%
  dplyr::summarise(Permafrost=Permafrost[Land_Use=="F"], 
                   Change = Land_Use[Land_Use!="F"],
                   forest_POM = POM_relative[Land_Use=="F"],
                   forest_DOC = DOC_relative[Land_Use=="F"],
                   forest_SA = SA_relative[Land_Use=="F"],
                   forest_SC = SC_rSOC_relative[Land_Use=="F"],
                   forest_rSOC = rSOC_relative[Land_Use=="F"],
                   new_POM = POM_relative[Land_Use!="F"],
                   new_DOC = DOC_relative[Land_Use!="F"],
                   new_SA = SA_relative[Land_Use!="F"],
                   new_SC = SC_rSOC_relative[Land_Use!="F"],
                   new_rSOC = rSOC_relative[Land_Use!="F"])%>%
  dplyr::group_by(Permafrost, Change) %>%
  dplyr::summarise(forest_POM = mean(forest_POM),
                   forest_DOC = mean(forest_DOC),
                   forest_SA = mean(forest_SA),
                   forest_SC = mean(forest_SC),
                   forest_rSOC = mean(forest_rSOC),
                   new_POM = mean(new_POM),
                   new_DOC = mean(new_DOC),
                   new_SA = mean(new_SA),
                   new_SC = mean(new_SC),
                   new_rSOC = mean(new_rSOC)) %>%
  reshape2::melt(., id.var=c("Permafrost", "Change")) %>%
  mutate(LU = case_when(startsWith(as.character(variable), "forest") ~ "Forest",
                        startsWith(as.character(variable), "new") ~ "New"),
         Fraction = case_when(endsWith(as.character(variable), "POM") ~ "POM",
                              endsWith(as.character(variable), "DOC") ~ "DOC",
                              endsWith(as.character(variable), "SA") ~ "SA",
                              endsWith(as.character(variable), "rSOC") ~ "rSOC",
                              endsWith(as.character(variable), "SC") ~ "SC"),
         Depth = "Topsoil",
         Change_PF = paste0(Change,c("_"), Permafrost))

fractions_subsoil_rel <- MS_data %>%
  filter(., Depth == 50) %>%
  dplyr::select(., c(Location, Land_Use,Permafrost,  POM_relative, DOC_relative, SA_relative, SC_relative)) %>%
  group_by(Location) %>%
  dplyr::summarise(Permafrost=Permafrost[Land_Use=="F"], 
                   Change = Land_Use[Land_Use!="F"],
                   forest_POM = POM_relative[Land_Use=="F"],
                   forest_DOC = DOC_relative[Land_Use=="F"],
                   forest_SA = SA_relative[Land_Use=="F"],
                   forest_SC = SC_relative[Land_Use=="F"],
                   new_POM = POM_relative[Land_Use!="F"],
                   new_DOC = DOC_relative[Land_Use!="F"],
                   new_SA = SA_relative[Land_Use!="F"],
                   new_SC = SC_relative[Land_Use!="F"])%>%
  dplyr::group_by(Permafrost, Change) %>%
  dplyr::summarise(forest_POM = mean(forest_POM),
                   forest_DOC = mean(forest_DOC),
                   forest_SA = mean(forest_SA),
                   forest_SC = mean(forest_SC),
                   new_POM = mean(new_POM),
                   new_DOC = mean(new_DOC),
                   new_SA = mean(new_SA),
                   new_SC = mean(new_SC)) %>%
  reshape2::melt(., id.var=c("Permafrost", "Change")) %>%
  mutate(LU = case_when(startsWith(as.character(variable), "forest") ~ "Forest",
                        startsWith(as.character(variable), "new") ~ "New"),
         Fraction = case_when(endsWith(as.character(variable), "POM") ~ "POM",
                              endsWith(as.character(variable), "DOC") ~ "DOC",
                              endsWith(as.character(variable), "SA") ~ "SA",
                              endsWith(as.character(variable), "SC") ~ "SC"),
         Depth = "Subsoil",
         Change_PF = paste0(Change,c("_"), Permafrost))

fractions_rel <- rbind(fractions_topsoil_rel, fractions_subsoil_rel)
fractions_rel$Fraction <- factor(fractions_rel$Fraction, levels = c("POM","DOC","SA", "SC", "rSOC"))
fractions_rel$Depth <- factor(fractions_rel$Depth, levels = c("Topsoil", "Subsoil"))

donut <- ggplot(fractions_rel, aes(x=LU, y=value, fill=Fraction))+
  geom_col()+
  geom_text(aes(label=round(value,digits = 2)), position=position_stack(vjust=0.5), color="white", size = 6)+
  facet_grid(Depth~Change_PF, labeller = as_labeller(labs))+
  scale_fill_colorblind()+
  scale_x_discrete(limits = c(" ", "Forest","New")) +
  coord_polar("y")+
  theme_bw(base_size = 20)+
  theme(axis.text.x = element_blank(),
        axis.text.y=element_blank(),axis.ticks=element_blank(),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        panel.background=element_blank(),panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),plot.background=element_blank(),rect = element_rect(fill = "transparent"))

donut

# statistics for the donut plot

test_data <- MS_data %>%
  filter(., Depth == 15) %>%
  dplyr::select(., c(Location, Land_Use,Permafrost,  POM_relative, DOC_relative, SA_relative, SC_rSOC_relative, rSOC_relative)) %>%
  group_by(Location) %>%
  dplyr::summarise(Permafrost=Permafrost[Land_Use=="F"], 
                   Change = Land_Use[Land_Use!="F"],
                   forest_POM = POM_relative[Land_Use=="F"],
                   forest_DOC = DOC_relative[Land_Use=="F"],
                   forest_SA = SA_relative[Land_Use=="F"],
                   forest_SC = SC_rSOC_relative[Land_Use=="F"],
                   forest_rSOC = rSOC_relative[Land_Use=="F"],
                   new_POM = POM_relative[Land_Use!="F"],
                   new_DOC = DOC_relative[Land_Use!="F"],
                   new_SA = SA_relative[Land_Use!="F"],
                   new_SC = SC_rSOC_relative[Land_Use!="F"],
                   new_rSOC = rSOC_relative[Land_Use!="F"])


test_data_relative_changes <- test_data %>%
  dplyr::summarise(POM = new_POM-forest_POM,
                   DOC = new_DOC-forest_DOC,
                   SA = new_SA-forest_SA,
                   SC = new_SC-forest_SC,
                   rSOC = new_rSOC-forest_rSOC,
                   Permafrost = Permafrost,
                   Change = Change)

# summary(aov(POM~Permafrost+Change, data = test_data_relative_changes))
# summary(aov(DOC~Permafrost+Change, data = test_data_relative_changes))
# summary(aov(SA~Permafrost+Change, data = test_data_relative_changes))
# summary(aov(SC~Permafrost+Change, data = test_data_relative_changes))
# summary(aov(rSOC~Permafrost+Change, data = test_data_relative_changes))

#adjust for the desired fraction
wilcox.test(test_data$forest_POM, test_data$new_POM, paired = TRUE, alternative = "greater")
wilcox.test(test_data$forest_DOC, test_data$new_DOC, paired = TRUE, alternative = "greater")
wilcox.test(test_data$forest_SA, test_data$new_SA, paired = TRUE,  alternative = "greater")
wilcox.test(test_data$forest_SC, test_data$new_SC, paired = TRUE, alternative = "less")
wilcox.test(test_data$forest_rSOC, test_data$new_rSOC, paired = TRUE, alternative = "less")


##### Figure 5: Stacked Barplot of fractions-------------

fractions_topsoil <- MS_data %>%
  filter(., Depth == 15) %>%
  dplyr::select(., c(Location, Land_Use,Permafrost, POM_C, DOC, SA_C,SC_C, rSOC)) %>%
  group_by(Location) %>%
  dplyr::summarise(Permafrost=Permafrost[Land_Use=="F"], 
                   Change = Land_Use[Land_Use!="F"],
                   forest_POM = POM_C[Land_Use=="F"],
                   forest_DOC = DOC[Land_Use=="F"],
                   forest_SA = SA_C[Land_Use=="F"],
                   forest_SC = SC_C[Land_Use=="F"],
                   forest_rSOC = rSOC[Land_Use=="F"],
                   new_POM = POM_C[Land_Use!="F"],
                   new_DOC = DOC[Land_Use!="F"],
                   new_SA = SA_C[Land_Use!="F"],
                   new_SC = SC_C[Land_Use!="F"],
                   new_rSOC = rSOC[Land_Use!="F"]) %>%
  dplyr::group_by(Permafrost, Change) %>%
  dplyr::summarise(forest_POM = mean(forest_POM),
                   forest_DOC = mean(forest_DOC),
                   forest_SA = mean(forest_SA),
                   forest_SC = mean(forest_SC),
                   forest_rSOC = mean(forest_rSOC),
                   new_POM = mean(new_POM),
                   new_DOC = mean(new_DOC),
                   new_SA = mean(new_SA),
                   new_SC = mean(new_SC),
                   new_rSOC = mean(new_rSOC)) %>%
  reshape2::melt(., id.var=c("Permafrost", "Change")) %>%
  mutate(LU = case_when(startsWith(as.character(variable), "forest") ~ "Forest",
                        startsWith(as.character(variable), "new") ~ "New"),
         Fraction = case_when(endsWith(as.character(variable), "POM") ~ "POM",
                              endsWith(as.character(variable), "DOC") ~ "DOC",
                              endsWith(as.character(variable), "SA") ~ "SA",
                              endsWith(as.character(variable), "rSOC") ~ "rSOC",
                              endsWith(as.character(variable), "SC") ~ "SC"),
         Depth = "Topsoil",
         Change_PF = paste0(Change,c("_"), Permafrost))

fractions_subsoil <- MS_data %>%
  filter(., Depth == 50) %>%
  dplyr::select(., c(Location, Land_Use,Permafrost, POM_C, DOC, SA_C, SC_inkl_rSOC)) %>%
  group_by(Location) %>%
  dplyr::summarise(Permafrost=Permafrost[Land_Use=="F"], 
                   Change = Land_Use[Land_Use!="F"],
                   forest_POM = POM_C[Land_Use=="F"],
                   forest_DOC = DOC[Land_Use=="F"],
                   forest_SA = SA_C[Land_Use=="F"],
                   forest_SC = SC_inkl_rSOC[Land_Use=="F"],
                   new_POM = POM_C[Land_Use!="F"],
                   new_DOC = DOC[Land_Use!="F"],
                   new_SA = SA_C[Land_Use!="F"],
                   new_SC = SC_inkl_rSOC[Land_Use!="F"])%>%
  dplyr::group_by(Permafrost, Change) %>%
  dplyr::summarise(forest_POM = mean(forest_POM),
                   forest_DOC = mean(forest_DOC),
                   forest_SA = mean(forest_SA),
                   forest_SC = mean(forest_SC),
                   new_POM = mean(new_POM),
                   new_DOC = mean(new_DOC),
                   new_SA = mean(new_SA),
                   new_SC = mean(new_SC)) %>%
  reshape2::melt(., id.var=c("Permafrost", "Change")) %>%
  mutate(LU = case_when(startsWith(as.character(variable), "forest") ~ "Forest",
                        startsWith(as.character(variable), "new") ~ "New"),
         Fraction = case_when(endsWith(as.character(variable), "POM") ~ "POM",
                              endsWith(as.character(variable), "DOC") ~ "DOC",
                              endsWith(as.character(variable), "SA") ~ "SA",
                              endsWith(as.character(variable), "SC") ~ "SC"),
         Depth = "Subsoil",
         Change_PF = paste0(Change,c("_"), Permafrost))

fractions <- rbind(fractions_topsoil, fractions_subsoil)
fractions$Fraction <- factor(fractions$Fraction, levels = c("POM","DOC","SA", "SC", "rSOC"))
fractions$Depth <- factor(fractions$Depth, levels = c("Topsoil", "Subsoil"))

figure_5 <- ggplot(fractions, aes(x=LU, y=value, fill = Fraction))+
  geom_bar(stat="identity", position = "stack")+
  facet_grid(Depth~Change_PF,scales="free", labeller = as_labeller(labs))+
  scale_fill_colorblind()+
  xlab("Land use")+
  ylab("Mean TOC [g/kg]")+
  theme_bw()

figure_5

# statistics for the barplot 
test_data_absolute <- MS_data %>%
  filter(., Depth == 15) %>%
  dplyr::select(., c(Location, Land_Use,Permafrost, POM_g, DOC_g, SA_g, SC_g, rSOC_g))%>%
  group_by(Location) %>%
  dplyr::summarise(Permafrost=Permafrost[Land_Use=="F"], 
                   Change = Land_Use[Land_Use!="F"],
                   forest_POM = POM_g[Land_Use=="F"],
                   forest_DOC = DOC_g[Land_Use=="F"],
                   forest_SA = SA_g[Land_Use=="F"],
                   forest_SC = SC_g[Land_Use=="F"],
                   forest_rSOC = rSOC_g[Land_Use=="F"],
                   new_POM = POM_g[Land_Use!="F"],
                   new_DOC = DOC_g[Land_Use!="F"],
                   new_SA = SA_g[Land_Use!="F"],
                   new_SC = SC_g[Land_Use!="F"],
                   new_rSOC = rSOC_g[Land_Use!="F"]) %>%
  filter(., Change == "C") %>%
  filter(., Permafrost == "Yes")

# adjust for the desired fraction
wilcox.test(test_data_absolute$forest_POM, test_data_absolute$new_POM, paired = TRUE, exact = TRUE, alternative = "greater")
wilcox.test(test_data_absolute$forest_DOC, test_data_absolute$new_DOC, paired = TRUE,exact = TRUE, alternative = "greater")
wilcox.test(test_data_absolute$forest_SA, test_data_absolute$new_SA, paired = TRUE, exact = TRUE, alternative = "greater")
wilcox.test(test_data_absolute$forest_SC, test_data_absolute$new_SC, paired = TRUE, exact = TRUE, alternative = "less")
wilcox.test(test_data_absolute$forest_rSOC, test_data_absolute$new_rSOC, paired = TRUE, exact = TRUE, alternative = "greater")



fit_data_grassland <- MS_data %>%
  filter(., Depth == 15) %>%
  filter(., Location =="DR" |
           Location =="DW" |
           Location =="MA" |
           Location =="PC" |
           Location=="TH"|
           Location=="CD"|
           Location=="EF"|
           Location=="GV"|
           Location=="MG"|
           Location=="VE") %>%
  filter(., Land_Use =="F" | Land_Use=="G")

fit_data_cropland <- MS_data %>%
  filter(., Depth == 15) %>%
  filter(., Location =="KK" |
           Location =="KL" |
           Location =="PC" |
           Location =="RC" |
           Location=="RFo"|
           Location=="RFy"|
           Location=="TH"|
           Location=="CD"|
           Location=="GV"|
           Location=="LR"|
           Location=="MG"|
           Location=="VE") %>%
  filter(., Land_Use =="F" | Land_Use=="C")

fit_POM_SA <- aov(POM_SA ~ Land_Use*Permafrost, data = fit_data_grassland)
TukeyHSD(fit_POM_SA)

fit_MAOM <- aov(MAOM ~ Land_Use*Permafrost, data = fit_data_grassland)
TukeyHSD(fit_MAOM)

summary(aov(SA_g ~ Land_Use*Permafrost, data = fit_data_grassland))
summary(aov(SC_C ~ Land_Use*Permafrost, data = fit_data_grassland))


#### Figure 6: Time dependend response----  

# Smoothing function with different behaviour depending on the panel
custom.smooth <- function(formula, data,...){
  smooth.call <- match.call()
  
  if(as.numeric(unique(data$PANEL)) == 2) {
    # polynomial fit
    smooth.call[[1]] <- quote(lm)
    # Specify formula
    smooth.call$formula <- as.formula("y ~ -1+x+I(x^2)")
  }else{
    # Linear fit
    smooth.call[[1]] <- quote(lm)
    # Specify formula
    smooth.call$formula <- NULL
  }
  
  # Perform fit
  eval.parent(smooth.call)
}

custom.smooth2 <- function(formula, data,...){
  smooth.call <- match.call()
  
  if(as.numeric(unique(data$PANEL)) == 2) {
    # polynomial fit
    smooth.call[[1]] <- quote(lm)
    # Specify formula
    smooth.call$formula <- as.formula("y ~ -1+x")
  }else{
    # Linear fit
    smooth.call[[1]] <- quote(lm)
    # Specify formula
    smooth.call$formula <- NULL
  }
  
  # Perform fit
  eval.parent(smooth.call)
}

relative_time <- sites %>%
  dplyr::select(., c(Change, Age, Permafrost, RR)) %>%
  ggplot(data = ., aes(x=Age, y=RR))+
  geom_point(size=3, aes(color = Change))+
  scale_color_colorblind(labels = c("Cropland", "Grassland"))+
  geom_abline(intercept = 0, slope = 0)+
  geom_smooth(method = "custom.smooth", fullrange = TRUE)+
  facet_grid(~Permafrost, labeller = as_labeller(labs))+
  ylab("Change in SOC stocks [%]")+
  xlab(NULL)+
  theme_bw()

absolute_time <- sites %>%
  dplyr::select(., c(Change, Age, Permafrost, Loss)) %>%
  ggplot(data = ., aes(x=Age, y=Loss))+
  scale_color_colorblind()+
  geom_point(size=3, aes(color = Change))+
  geom_abline(intercept = 0, slope = 0)+
  facet_grid(~Permafrost,scales = "free", labeller = as_labeller(labs))+
  ylab("Change in SOC stocks [Mg / ha]")+
  xlab("Time since conversion from forest [Years]")+
  theme_bw()

figure_6 <- ggarrange(relative_time, absolute_time, ncol = 1, common.legend = TRUE)

figure_6

##### Figure 7: Correlation plot------

# function for computing p-values

cor.mtest <- function(mat, ...) {
  mat <- as.matrix(mat)
  n <- ncol(mat)
  p.mat<- matrix(NA, n, n)
  diag(p.mat) <- 0
  for (i in 1:(n - 1)) {
    for (j in (i + 1):n) {
      tmp <- cor.test(mat[, i], mat[, j],method = "spearman",exact = FALSE, ... =  )
      p.mat[i, j] <- p.mat[j, i] <- tmp$p.value
    }
  }
  colnames(p.mat) <- rownames(p.mat) <- colnames(mat)
  p.mat
}

# select data for the correlation-matrix
correlation_matrix <- sites_cor %>%
  ungroup() %>%
  dplyr::select(., c(forest_stock, forest_POM, forest_DOC, forest_SA, forest_SC, forest_rSOC, RR, delta_POM, delta_DOC, delta_SA, delta_SC, 
                     delta_rSOC, forest_a_horizon, Permafrost_depth,  Age, Litter_C, Profile_CN_F, Sand_F, Silt_F, Clay_F, Olsen_P_F,
                     ph_F, cumulative_degree_days, frost_days, temperature, precipitation, longitude, latitude))

# assign convenient names of the variables
colnames(correlation_matrix) <- c("SOC stock Forest",  "POM forest", "DOC forest","SA forest", "SC forest", "rSOC forest", "\U0394 stock", 
                                  "\U0394 POM",  "\U0394 DOC",  "\U0394 SA",  "\U0394 SC",  "\U0394 rSOC",  
                                  "A-horizon thickness", "Permafrost depth", "Time since conversion", "Litter C stock", "C:N", "Sand", "Silt", "Clay", "Olsen-P",
                                  "pH", "Cumulative degree days", "Frost days", "Mean annual temperature", "Annual precipitation",
                                  "Longitude", "Latitude")

# calculate the correlation coefficients as a correlation matrix
correlation_table <- cor(correlation_matrix, method = "spearman")
p.mat <- cor.mtest(correlation_matrix) # creates p-values
corrplot <- corrplot::corrplot(correlation_table, 
                               method = "circle", type = "upper", p.mat = p.mat, 
                               sig.level = c(0.001, 0.01, 0.05), tl.srt = 45, insig = "label_sig", tl.col = 'black',
                               pch.cex = 0.7,
                               pch.col = "white")


###### Figure S1: Soil organic carbon stocks for every plot----------------
site_bars <- SS_data %>%
  filter(Depth == 70 | (Location == "NB" & Depth == 30)) %>%
  filter(., Location != "NO") %>%
  group_by(Location, Land_Use) %>%
  summarise(Stock_mean = mean(C_Complete),
            Stock_sd = sd(C_Complete))

site_bars$Location <- factor(site_bars$Location, levels = c("DR", "DW", "KK", "KL", "MA", "MG", "PC", "RC", "RFo", "RFy", "SI", "TH", "CD", "EF", "EG", "GV", "LR", "NB", "VE"))


figure_S1 <- ggplot(data = site_bars, aes(x=Land_Use, y=Stock_mean, fill=Land_Use))+
  geom_bar(stat="identity")+
  geom_errorbar(aes(ymin = Stock_mean-Stock_sd, ymax=Stock_mean+Stock_sd, width = 0.3))+
  scale_fill_colorblind(name = element_blank(),labels = c("Forest", "Cropland", "Grassland"))+
  facet_wrap(~Location, scales="free", labeller = as_labeller(permafrost_labs))+
  ylab("SOC stock [Mg/ha]")+
  xlab(element_blank())+
  theme_bw()+
  theme(legend.position = c(0.9, 0.12), 
        plot.tag.position = c(0.9, 0.07), 
        plot.tag = element_text(size = 10))

figure_S1

###### Figure S2: total organic carbon for every plot and sampling depth----------------
TOC <- SS_data %>%
  group_by(Location, Depth, Land_Use) %>%
  summarise(TOC_mean = mean(`TOC [%]`)*10,
            TOC_sd = sd(`TOC [%]`)*10) 

TOC$Location <- factor(TOC$Location, levels = c("DR", "DW", "KK", "KL", "MA", "MG", "PC", "RC", "RFo", "RFy", "SI", "TH", "CD", "EF", "EG", "GV", "LR", "NB", "VE"))

figure_S2 <- ggplot(data = TOC)+
  geom_pointrange(aes(x=TOC_mean, xmax=TOC_mean+TOC_sd, xmin = TOC_mean-TOC_sd, y=Depth*-1, color = Land_Use))+
  geom_path(aes(x=TOC_mean, y=Depth*-1, color = Land_Use))+
  scale_color_colorblind()+
  ylab("Depth [cm]")+
  xlab(element_blank())+
  facet_wrap(~Location, scales="free", labeller = as_labeller(permafrost_labs))+
  theme_bw()+
  theme(legend.position = c(0.9, 0.12))

figure_S2

